@@ -27,7 +27,6 @@
 #include <konq_events.h>
 #include "konqviewmanager.h"
 #include "konqtabs.h"
-#include "konqbrowseriface.h"
 #include "konqhistorymanager.h"
 #include "konqpixmapprovider.h"
 
@@ -108,7 +107,6 @@ KonqView::KonqView(KonqViewFactory &viewFactory,
     m_bDisableScrolling = false;
     m_bGotIconURL = false;
     m_bPopupMenuEnabled = true;
-    m_browserIface = new KonqBrowserInterface(this);
     m_bFollowActive = false;
     m_bBuiltinView = false;
     m_bURLDropHandling = false;
@@ -388,8 +386,6 @@ void KonqView::connectPart()
     KParts::BrowserExtension *ext = browserExtension();
 
     if (ext) {
-        ext->setBrowserInterface(m_browserIface);
-
         connect(ext, SIGNAL(openUrlRequestDelayed(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
                 m_pMainWindow, SLOT(slotOpenURLRequest(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)));
 
@@ -782,17 +778,6 @@ void KonqView::updateHistoryEntry(bool saveLocationBarURL)
     current->pageReferrer = m_pageReferrer;
 }
 
-void KonqView::goHistory(int steps)
-{
-    // This is called by KonqBrowserInterface
-    if (m_pMainWindow->currentView() == this) {
-        m_pMainWindow->viewManager()->setActivePart(part());
-    }
-
-    // Delay the go() call (we need to return to the caller first)
-    m_pMainWindow->slotGoHistoryActivated(steps);
-}
-
 void KonqView::go(int steps)
 {
     if (!steps) { // [WildFox] i bet there are sites on the net with stupid devs who do that :)
@@ -1209,11 +1194,11 @@ bool KonqView::eventFilter(QObject *obj, QEvent *e)
         }
     }
 
+#ifdef KActivities_FOUND
     if (e->type() == QEvent::FocusIn) {
-        setActiveComponent();
+        m_activityResourceInstance->notifyFocusedIn();
     }
 
-#ifdef KActivities_FOUND
     if (e->type() == QEvent::FocusOut) {
         m_activityResourceInstance->notifyFocusedOut();
     }
@@ -1222,22 +1207,6 @@ bool KonqView::eventFilter(QObject *obj, QEvent *e)
     return false;
 }
 
-void KonqView::setActiveComponent()
-{
-#if 0 // Removed with the port to KF5. The concept no longer exists, the about dialog and bug report
-    // dialog just use the application information rather than the one of the current part.
-    if (m_bBuiltinView) {
-        KComponentData::setActiveComponent(KGlobal::mainComponent());
-    } else {
-        KComponentData::setActiveComponent(KComponentData(m_pPart->componentData()));
-    }
-#endif
-
-#ifdef KActivities_FOUND
-    m_activityResourceInstance->notifyFocusedIn();
-#endif
-}
-
 bool KonqView::prepareReload(KParts::OpenUrlArguments &args, KParts::BrowserArguments &browserArgs, bool softReload)
 {
     args.setReload(true);
@@ -1298,13 +1267,13 @@ bool KonqView::supportsMimeType(const QString &mimeType) const
 
 void HistoryEntry::saveConfig(KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options)
 {
-    if (options & KonqFrameBase::saveURLs) {
+    if (options & KonqFrameBase::SaveUrls) {
         config.writeEntry(QStringLiteral("Url").prepend(prefix), url.url());
         config.writeEntry(QStringLiteral("LocationBarURL").prepend(prefix), locationBarURL);
         config.writeEntry(QStringLiteral("Title").prepend(prefix), title);
         config.writeEntry(QStringLiteral("StrServiceType").prepend(prefix), strServiceType);
         config.writeEntry(QStringLiteral("StrServiceName").prepend(prefix), strServiceName);
-    } else if (options & KonqFrameBase::saveHistoryItems) {
+    } else if (options & KonqFrameBase::SaveHistoryItems) {
         config.writeEntry(QStringLiteral("Url").prepend(prefix), url.url());
         config.writeEntry(QStringLiteral("LocationBarURL").prepend(prefix), locationBarURL);
         config.writeEntry(QStringLiteral("Title").prepend(prefix), title);
@@ -1321,20 +1290,17 @@ void HistoryEntry::saveConfig(KConfigGroup &config, const QString &prefix, const
 
 void HistoryEntry::loadItem(const KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options)
 {
-    if (options & KonqFrameBase::saveURLs) {
+    if (options & (KonqFrameBase::SaveUrls|KonqFrameBase::SaveHistoryItems)) { // either one
         url = QUrl(config.readEntry(QStringLiteral("Url").prepend(prefix), ""));
         locationBarURL = config.readEntry(QStringLiteral("LocationBarURL").prepend(prefix), "");
         title = config.readEntry(QStringLiteral("Title").prepend(prefix), "");
         strServiceType = config.readEntry(QStringLiteral("StrServiceType").prepend(prefix), "");
         strServiceName = config.readEntry(QStringLiteral("StrServiceName").prepend(prefix), "");
+    }
+    if (options & KonqFrameBase::SaveUrls) {
         reload = true;
-    } else if (options & KonqFrameBase::saveHistoryItems) {
-        url = QUrl(config.readEntry(QStringLiteral("Url").prepend(prefix), ""));
-        locationBarURL = config.readEntry(QStringLiteral("LocationBarURL").prepend(prefix), "");
-        title = config.readEntry(QStringLiteral("Title").prepend(prefix), "");
+    } else if (options & KonqFrameBase::SaveHistoryItems) {
         buffer = config.readEntry(QStringLiteral("Buffer").prepend(prefix), QByteArray());
-        strServiceType = config.readEntry(QStringLiteral("StrServiceType").prepend(prefix), "");
-        strServiceName = config.readEntry(QStringLiteral("StrServiceName").prepend(prefix), "");
         postData = config.readEntry(QStringLiteral("PostData").prepend(prefix), QByteArray());
         postContentType = config.readEntry(QStringLiteral("PostContentType").prepend(prefix), "");
         doPost = config.readEntry(QStringLiteral("DoPost").prepend(prefix), false);
@@ -1354,9 +1320,9 @@ void KonqView::saveConfig(KConfigGroup &config, const QString &prefix, const Kon
     config.writeEntry(QStringLiteral("ToggleView").prepend(prefix), isToggleView());
     config.writeEntry(QStringLiteral("LockedLocation").prepend(prefix), isLockedLocation());
 
-    if (options & KonqFrameBase::saveURLs) {
+    if (options & KonqFrameBase::SaveUrls) {
         config.writePathEntry(QStringLiteral("URL").prepend(prefix), url().url());
-    } else if (options & KonqFrameBase::saveHistoryItems) {
+    } else if (options & KonqFrameBase::SaveHistoryItems) {
         if (m_pPart && !m_bLockHistory) {
             updateHistoryEntry(true);
         }
@@ -1366,9 +1332,9 @@ void KonqView::saveConfig(KConfigGroup &config, const QString &prefix, const Kon
             // history for current history item
             KonqFrameBase::Options options;
             if (i == m_lstHistoryIndex) {
-                options = KonqFrameBase::saveHistoryItems;
+                options = KonqFrameBase::SaveHistoryItems;
             } else {
-                options = KonqFrameBase::saveURLs;
+                options = KonqFrameBase::SaveUrls;
             }
 
             (*it)->saveConfig(config, QLatin1String("HistoryItem")
@@ -1401,9 +1367,9 @@ void KonqView::loadHistoryConfig(const KConfigGroup &config, const QString &pref
         // Only current history item saves completely its HistoryEntry
         KonqFrameBase::Options options;
         if (i == currentIndex) {
-            options = KonqFrameBase::saveHistoryItems;
+            options = KonqFrameBase::SaveHistoryItems;
         } else {
-            options = KonqFrameBase::saveURLs;
+            options = KonqFrameBase::SaveUrls;
         }
 
         historyEntry->loadItem(config, QLatin1String("HistoryItem") + QString::number(i).prepend(prefix), options);
